pub struct ArchetypeWriter<'a> { /* private fields */ }
Provides access to writers for writing new entities into an archetype in a world.

Users must claim all components contained in the archetype and write an equal number of components to each as the number of entities pushed to the writer.

Implementations

source

impl<'a> ArchetypeWriter<'a>

source

pub fn new( arch_index: ArchetypeIndex, archetype: &'a mut Archetype, components: MultiMut<'a> ) -> ArchetypeWriter<'a>

Constructs a new archetype writer.

source

pub fn archetype(&self) -> &Archetype

Returns the archetype being written to.

source

pub fn claim_components<T>(&mut self) -> ComponentWriter<'a, T>
where T: Component,

Claims a component storage for a given component.

Panics

Panics if the storage for the requested component type has already been claimed or does not exist in the archetype.

source

pub fn claim_components_unknown( &mut self, type_id: ComponentTypeId ) -> UnknownComponentWriter<'a>

Claims a component storage for a given component.

Panics

Panics if the storage for the requested component type has already been claimed or does not exist in the archetype.

source

pub fn push(&mut self, entity: Entity)

Pushes an entity ID into the archetype.

source

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional extra entity IDs in the archetype.

source

pub fn inserted(&self) -> (ComponentIndex, &[Entity])

Returns a slice of entities inserted by this writer, and the component index of the first inserted entity.