Struct kaige::storage::PackedStorage
source · pub struct PackedStorage<T>where
T: Component,{ /* private fields */ }Expand description
Stores a slice of components of type T for each archetype.
Archetype slices are sorted according to the group that component T belongs to.
Each slice may be packed into a single allocation to optimise for group-based access.