Struct kaige::storage::ArchetypeWriter
source · pub struct ArchetypeWriter<'a> { /* private fields */ }Expand description
Provides access to writers for writing new entities into an archetype in a world.
Users must claim all components contained in the archetype and write an equal number of components to each as the number of entities pushed to the writer.
Implementations
sourceimpl<'a> ArchetypeWriter<'a>
impl<'a> ArchetypeWriter<'a>
sourcepub fn new(
arch_index: ArchetypeIndex,
archetype: &'a mut Archetype,
components: MultiMut<'a>
) -> ArchetypeWriter<'a>
pub fn new( arch_index: ArchetypeIndex, archetype: &'a mut Archetype, components: MultiMut<'a> ) -> ArchetypeWriter<'a>
Constructs a new archetype writer.
sourcepub fn claim_components<T>(&mut self) -> ComponentWriter<'a, T>where
T: Component,
pub fn claim_components<T>(&mut self) -> ComponentWriter<'a, T>where
T: Component,
Claims a component storage for a given component.
Panics
Panics if the storage for the requested component type has already been claimed or does not exist in the archetype.
sourcepub fn claim_components_unknown(
&mut self,
type_id: ComponentTypeId
) -> UnknownComponentWriter<'a>
pub fn claim_components_unknown( &mut self, type_id: ComponentTypeId ) -> UnknownComponentWriter<'a>
Claims a component storage for a given component.
Panics
Panics if the storage for the requested component type has already been claimed or does not exist in the archetype.
sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional extra entity IDs in the archetype.
sourcepub fn inserted(&self) -> (ComponentIndex, &[Entity])
pub fn inserted(&self) -> (ComponentIndex, &[Entity])
Returns a slice of entities inserted by this writer, and the component index of the first inserted entity.